# cvebase-wiki

## Installation

```
python3 -m pip install cvebase-wiki --upgrade
```

## Usage

Lint CVE & Researcher markdown files

```
cvebase-wiki lint -r <path to cvebase.com repo>
```

Edit CVE file

```
cvebase-wiki edit --cve CVE-2020-14882
```

Edit Researcher profile

```
cvebase-wiki edit --researcher orange
```
